from jd.api.base import RestApi

class VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderReturnAddressRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)

		def getapiname(self):
			return 'jingdong.vender.seller.web.controller.open.venderAddr.VenderAddrFacade.listVenderReturnAddress'

			




